==> haskell-persistent-sqlite-2.2-24-armv7h.pkg.tar.xz: usr/share/haskell/haskell-persistent-sqlite/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.2
id: persistent-sqlite-2.2-04957afc1b3cdca0c52cbee96984a045
key: persi_9ncYKGPwgCJ0i8493T9N2b
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Sqlite Database.Persist.Sqlite
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-sqlite-2.2
hs-libraries: HSpersistent-sqlite-2.2-9ncYKGPwgCJ0i8493T9N2b
extra-libraries:
    pthread
depends:
    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    monad-logger-0.3.18-1a8cc90bb0cf2afc03da9e875eb23203
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    persistent-2.2.4-72be3212e3a1e06e6072e64a9625ec8e
    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-sqlite-2.2-25-armv7h.pkg.tar.xz: usr/share/haskell/haskell-persistent-sqlite/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.2
id: persistent-sqlite-2.2-737228c9d4f8f76d3f85a49af35cc3f4
key: persi_21fxqYMoYJT8BMzrSfE3ME
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Sqlite Database.Persist.Sqlite
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-sqlite-2.2
hs-libraries: HSpersistent-sqlite-2.2-21fxqYMoYJT8BMzrSfE3ME
extra-libraries:
    pthread
depends:
    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    monad-logger-0.3.18-ff79344a77beba20df980e6518219c42
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    persistent-2.2.4-a4a8972281cfa07170d8ccc96de1b890
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
